/*
 * Author: Yevgeniy Kiveisha <yevgeniy.kiveisha@intel.com>
 * Copyright (c) 2014 Intel Corporation.
 *
 * Permission is hereby granted, free of charge, to any person obtaining
 * a copy of this software and associated documentation files (the
 * "Software"), to deal in the Software without restriction, including
 * without limitation the rights to use, copy, modify, merge, publish,
 * distribute, sublicense, and/or sell copies of the Software, and to
 * permit persons to whom the Software is furnished to do so, subject to
 * the following conditions:
 *
 * The above copyright notice and this permission notice shall be
 * included in all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND,
 * EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF
 * MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND
 * NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS OR COPYRIGHT HOLDERS BE
 * LIABLE FOR ANY CLAIM, DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION
 * OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 * WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 */
#pragma once

#include <string>
#include <mraa/i2c.hpp>

namespace upm
{
/**
 * @brief I2C LCD display library
 * @defgroup i2clcd libupm-i2clcd
 * @ingroup seeed sparkfun adafruit i2c display gsk
 */
class LCD
{
  public:
    LCD(int bus, int lcdAddress);
    virtual ~LCD();
    mraa_result_t write(int x, int y, std::string msg);

    virtual mraa_result_t write(std::string msg) = 0;
    virtual mraa_result_t setCursor(int row, int column) = 0;
    virtual mraa_result_t clear() = 0;
    virtual mraa_result_t home() = 0;
    virtual mraa_result_t createChar(uint8_t charSlot, uint8_t charData[]);

    std::string name();

  protected:
    std::string m_name;
    int m_lcd_control_address;
    int m_bus;

    mraa::I2c m_i2c_lcd_control;
};
}
